
# Slot: readonly


If present, slot is read only.  Text explains why

URI: [linkml:readonly](https://w3id.org/linkml/readonly)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
